@@ -1043,7 +1043,9 @@ expvar (struct mu_wordsplit *wsp, const char *str, size_t len,
       else
 	rc = MU_WRDSE_UNDEF;
 
-      if (rc == MU_WRDSE_OK && value[0] == 0 && defstr && defstr[-1] == ':')
+      if (rc == MU_WRDSE_OK
+	  && (!value || value[0] == 0)
+	  && defstr && defstr[-1] == ':')
 	{
 	  free (value);
 	  rc = MU_WRDSE_UNDEF;
@@ -2140,6 +2142,7 @@ mu_wordsplit_process_list (struct mu_wordsplit *wsp, size_t start)
       /* Treat entire input as a quoted argument */
       if (mu_wordsplit_add_segm (wsp, start, wsp->ws_len, _WSNF_QUOTE))
 	return wsp->ws_errno;
+      wsp->ws_endp = wsp->ws_len;
     }
   else
     {
